#!/usr/bin/env node
import { Language, Schema } from "./models";
interface Arguments {
    /**
     * The names of the tables to load
     */
    tables: Array<keyof Schema.DB>;
    /**
     * The path to the database.
     * Can be either absolute or relative.
     * If the database is not at the specified path,
     * it will be copied from the default path in the node_modules.
     */
    database: string;
    /**
     * The directory for caching
     */
    cachedir?: string;
    /**
     * The duration in ms for items to stay in in-memory cache
     */
    cacheduration?: number;
    /**
     * In which languages the tables will be loaded. Default: English
     */
    languages?: Array<Language>;
    /**
     * Whether duplicate key errors are ignored on insertion. Default: true
     */
    silent?: boolean;
    /**
     * Whether to remove unused tables, that is, all tables not in `tables`.
     * Default: false
     */
    removeUnusedTables?: boolean;
}
/**
 * Loads a database with the given config & tables
 *
 * @param config The config to use
 */
export declare function loadTables(config: Arguments): Promise<void>;
export declare function clearDb(dbPath: string): Promise<void>;
export declare function main(): Promise<void>;
export {};
